
# q-expansion of newform 2.56.a.b, downloaded from the LMFDB on 04 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2
weight = 56
poly_data = [5032749353671885590018834040, -9638486409249116938, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0], 1], [[-4112420868232128183680, 857514869760, 640], 143886491], [[193682685578616648184959360, 117149300824366080, -30142080], 143886491]]

hecke_ring_character_values = None
aps_data = [[-134217728, 0, 0], [1035669549772, -1, 0], [6749230845018069870, -43029, 7], [91664652332094024413816, 6064364682, 50020], [22709191600824521299897885572, 212191030774989, -3430232120], [249213813505499986738550840102, -229247821273229397, 1001805114695], [78508750745980156805425504192626, 265943691958044452418, 1788220936976810], [-65116346180013259929414940933839940, 6136652914848845276931, 23047470673881080], [-19138536696015259178573856159591926808, 626123660253165577330254, 1941737489563843580], [4129352894125655857345757414649610462230, -12232186338546043203354993, -3987922474931678279045], [-46139001700499896236089966997944824837408, -2401441478995293545546675592, 15416663868214212989280], [3189383727613605550177252066998283015447886, 763817130493678968320618741583, -4733991548498243748106565], [45936140721526597132490575358431566174463962, 926260711734212022940348646772, -29180839806529770549010940], [932909209843921782340834562963927075363998052, -9572068778532579232238847855123, -134263148142809916378639120], [-1367178873040550687400924439725286960184985264, 33281575689354001106205906352332, -2360797114098028354272685560], [-140455853539681953030784186666960505654640638658, -10404145142415142024975628137840017, 15075394737725757647583969115], [-635043167605826474672700647414643759313198458540, -94620962252475805136121618255812151, 1154272948879800660811526128160], [6216805006103044025328484729562324555137168161782, 153616417866443440736807106873928851, -3072519660236647225145959327665], [20115064722532128401041862082357134576383688895116, -7782813573974891598473696610872745849, -10858005189910229441659453725960], [-36756161573303280486013793660038133552418531328968, 18970393350460132792435634032256516106, 406018834301938843356874562993780], [-476873207250157520787403544427262273210443347712838, 3416858349330404294718565205733334218, -685403308588787545779423290104110], [10059780757359628411504613849977074985760826846513200, 164028072709330672592095229938686282756, -1962304133836366817003043383905240], [71286896368078999948185729225442184147667669054526332, 1466528851836288279231769417158748369755, -3478859865716814428398174284543360], [-194859204415577209776630117800793399810736944992082390, -17417771683504434946650355760943744539670, 65903925415520005167394692892046450], [3736172635582665381255600416405174711414544143379697826, -112127533975237810647229066637330189612310, 184338982345383987654732867586866290], [-2713848478069184399209697490894646236495404011776503538, -18036153443154590807172657318726930021033, -3578443020087816386001248588804767645], [10848451866351566858958037261254722750961596095322064152, 1052057804290526163855121326308915724614130, 3183188177926549779903601154595696900], [-34804133043364829714545743213388287067697595514507027164, 1847333774244764202019743357186399094086981, 22893429712444107069689003171245108600], [-87037757619576055860111560787981003530551226038293549370, -1962042203316008592338478544080536661344457, 9105844269661313446900077930862765635], [59338069806474352246971535718222323293462746185098257682, 4488035401017060734640052497709162696217904, 108841393920676847408683442866926320880], [1903812358726222702053145171735558430368744456865028864896, 256804087679808635287231952786440981249363056, 2494831480426642553107062627391783803600], [-5883958479218661871290990595889808535959265880294112484788, 676990628475870024087117164215417201030097607, -5146509671458946399984405972407136087480], [-9744417809371318135004725400934716996162133932516104188294, 1586590049736314632372409325242091682622669412, -6812611092918250539659243321263809048140], [26131612279714474634977911490154987299082933607487979973380, 2578398188937997064969300647047621587072530389, -1613260980468770399044435763977587646640], [-487556616123514867907880444704316028950069968004128483983650, 1063270099276019122085252489542924186819299675, 46872181433077980310934859433066539846455], [675089374937225647962422299308684301998214735755681473173352, -8848070196609872748413835841865918573029718610, 369024424340605491980588689895259027522300], [907412670343408221539347067698282453682009609162611232105366, -86727733686446997901180163706196259659431171813, -388777235254322457559830886278420570804105], [-2256569661055404645054174099961323087013845496019212315602388, 107682638388401100838120655590327764401533028295, 584604630213070703983262794458309781518160], [-2465681630713564021952231496359976801134320248358132477862184, -137089463431769268199430613680531143843252736814, -713558672481434872447263968664962288713740], [-22112349527905494858564362411970470600386142041591436463513978, 241024746062842032095330983236402862689791371395, 2577094398463719732536816617153995895000575], [-12911382838564099762275823614965385688847663014812583903015140, -4865526482854955183297832638670862670139143958957, -448826760987467125621728068718375590186960], [38630732201268578433731042334867711745353365804345280702487742, -197002865440749988827818527744204300915755405597, -35586958434782840113349794101546401613690785], [-568141530959390767831397981516831417462137561681699184671397568, -3502918429894887285550809105218229501638761683264, -73985254309998037424931340790020179372376720], [295666862537947817670375120835666046149551413456113715210936642, 51290893119532777978834550414259478272538493549370, -61707224152370636100808974205030411265307390], [206516146397311809929210121687013728412415445961590055266258606, 36833338147694150142584509135802881612984232843331, -284925597276002720760991917764330759867265985], [1048202953810273844886352091963995009872376945722166125293023160, -50338273366862001160736707919599213231893929485158, -601451184974918542309232490764115863177663260], [-2547500904972406485949958531542481608798202494382154075637542148, -36194020592823121911990435159878233073470004582805, -136485305889520961982754176580795108743598480], [28990587249498522499062963489138935948695289690784449546089989152, 357896165774199204267452474812319977914113135355336, 5599743557489181798919544162289160140607917600], [-5587949107579981987445287190962800991835199970431752683866433044, -670712156875817206104784394917935397781368146071577, -22059418638427601008483623964905351370035482880], [60459007400655614014678070946422951997013569557253052466814466190, 1273304031396825660898380932818807412286433028928579, 33970021015010808523280298960573991592288236095], [-40048426051428030787208925525945242231854411108199757719324297958, 3146520143970639875470970445074610012024904659336282, -15310584486127586474993446031914806430554827870], [269436732853379888136214155355073139165239679925769358103750212240, -2720863958961132894323091751512354415140181566275124, 4151639526796584161341952138300866255111886520], [-60904539259302214621929298129323246986686332943771441871686354798, 11832670726974821375925078271163713408321620854712930, -15892106203229943359009904672744756593725149110], [55756091382233454673431991519173733333914094867125255634689096852, -16052154760071956664446275733634010611177254784554535, 399666014040129403379189795213422075072982179360], [-442236886827332140274041777216384932713496372417198923160731699454, 22488854936715956648553194673775204598049813107353728, -10751493111456030095502690643293566608536547200], [-132221027609888452400815217080429404091899093946920851453103990408, 194941229527562994216294743323953694988048029914703386, -976884878550673699079304230287387187146637029900], [1552018548865674912769412724043486605742680908596196681620329605670, -378436533300599866927787403938577326404783002263498097, 514287084922724657627968017413286845822110604155], [1280872836907722502496984128486294115448300860272806952939293088112, 107268879085938243235798259183236802826982785302424612, -2040508496786914559432220516368357317787132931720], [10622701743198808662131786698371642501492822760918700943536174904926, -1190802263464144162796005002904318967717025718758513, -408673331411304880676565694918327815152147664645], [-27269414639313294722389389454705569963990928664373251282821118696598, 376842058927711052946779605485245740759107040038382530, 835128889174230868753873300928126160272355601450], [-7766937433846046606277557823118122225849968745233774636379997960588, 434717359052412710179662812399039041649496496297627881, 9204925670716778392716345321318853461729138174840], [-20752415108608182477875773805215243740726336193529060590103784692658, 255055815750269425490597132987943495861719876469723795, -3398341209295434405096580013979685677936649065265], [95530520604512483382679322095184478875240555281736509388247697395356, -7629970168882765878584845160368242480992284935753249285, 4257608018470920974650815155223081020289146160600], [145678977567205669111310479437823318370140245059658054212872398184392, -11908714722225570455728838680532046335145418229010829722, -67375751595184495619712155221339738272960261992900], [47486802056862483340757168438796331162207049453992966460869914958922, 5580488721568434752212241188974217951425149607481396692, -71594658554343189041111515597291444172432548429340], [152660670965461473500906305442390200601177080587791198055636177554166, -22886087818969865679583277563538315570992198715754601809, 113705785862304925850914512816341473413566347505435], [836577729107150382868418900277691076746806926892964455522517120955972, -95860229187539865539949094146793803431971245514370577171, -403384712291869783281741035068329315550311896904520], [-3489637064009422585505907427906925325958341939706514083763713519682254, -149762537416842538782014821213845929268945753662679442680, 431650078253762869805116323280751013436725655086760], [-21008473643245731580487944702715615787419540197736472727455491923404, 261968912698958926813233965834035774755842854141319896209, -3028005173324248333066821620038248737320401975271920], [9715614016448962956792062135845796255950112871494341167268597057747670, -93432126183041769726099301065155487863845356803869211721, 1185403595964012527351878235332036021637407778464195], [-4201787795598854869280085864967981438488581330643277905399614506532958, 395229983299402551400901416241694382921529886151787862888, 709387930277623557150474874145809832061800143786120], [-5927312990872041286930907546881638424425168824795258279581837740954600, 550009015734340983880479837453251310636167374938009188082, 5960070648768837358087974586933508031713358649126980], [36287986331022232164895503062301573564043681862755636525335721442690576, -315902499166226950464035580579223323759145523185968046212, -1731767567912612129806503106561941222187784207348280], [27501999560155995878541901707733608204260408930983636477490558297933822, 496431157620384348330969148916910956338175131999214652375, 13968637236053185012335255792046890684961577582577635], [95800083565760048477737379638288508457290173782502263940733869180892180, 182195044424973193236312655011247419556762258795727303817, -79837129478659565613266321072868002958377874030800], [-67381986590012707126556981532349979108345583712497895031934288133377408, -685962750007458738777248780077035487539432353888113098528, -36503587098161149189094931460097695647725717994946880], [-57341301486136484740351316158852388825966481148984408744272342086487570, 5097875793905133558496396498706099107123598509863289493439, 3626309468678623194062331832735720691404977785240555], [196660162511743902369619804627179483232234410722084645126834919914932646, -273041485050323574225330110915383275932277787043459321001, -89351939446069326281671872278787926720657155032560925], [87274093864547508725584317056207716468832062394536544411699783624051442, 22813646486399858735633674928489410973951962430747113458, 114831941763860807524699181245539198408858425299000090], [723395367155200586209016170293109567799764197281220141601490645458198250, 21623365939283431385281382898880134814442858985473349134052, -110447459446766413342886374258826175445474852389268940], [-1772681141811249398690239759401957174981021017835969433518324856033996500, -331751531251718073698864995130240054547335929503456689841, -112777092010614300219157414812027055763874008834292360], [-295987185391277865438747174184973543606605747787376391314420394850075698, -65097327957583900940502277698680781558286288480963899532005, 17998922232021114066591291237790090650364838313597175], [-2059265677080175129914455308400289981290843313850010389935867252506649648, -69409538634069376795378411629724614141064554279879791003940, -711569330513282721593396114638853930394549512323454920], [3623550029756933469155541035215333044353546259067036354614443553726233042, -34337076081474270933158568209132344064784960229746402980238, -296925349831735261626188053522434694306809637577945190], [901326346829116834051561645831646570607684882421199058072188980368712520, -137258204346557177561978932305948151483234857947017480167738, 100303988027354931067480159772958612557593238626214460], [-1805501273611777503195049843518544241148936185685418456259360022480461868, -427013128583326852244904961564150444432487531929344359972367, 1590835273341286835934942436492286600039378712405331080], [-1891309096827119184618401738396770093176701129410355641824992642597185470, 498227685944964453056518628324158817562302138827053111721626, 931270510566266922256877983491139870117526975985116130], [-4407607640337477160343247623623812619164371398121300358727430039415556294, 680914618033488366388519931263696297542901315450625088050340, 947337913301452720296160223594699240381014323350852340], [5742510637659705655570636444010003732250468512024005541266552996255545702, 653872175726658420670017051164262703923587965456048058813535, 2080795070116073316051781302379726154833515706472169355], [-22021503023619006459471005616631998202686663968741067930464025144718554448, 416345055277904080284547752577909223907876793376855936121828, 3087429877576039422229261816823508058320549232551002600], [7478579361202338654594617914624510286289227986429731390098101239456248316, 1111962724530392343054016298817737759044541751490654722703971, -4902003438589292570133774070937630338255769637888038840], [25151025356097457949097892172125743321357931274401630467979968556855737120, 712338052710125012350997105509759229016970524571038851438280, 11078875638247623193379144088139994304367565524850920800], [7029592796128521465176080050190724975676281583230624783523710822542704536, 359140247259524013325681004062331843858563856920276843771458, 5425044026619039011210040203251752303683035484153240180], [-13999130470184745392186289989766851383736736056648513514602391902447266908, -2581345017459544917114512915323325342558463868319910836141427, -44819655194423151082024428201003512830083996565244041600], [7744652391689369694221172082474666373772623021575678258389461641317879260, -766831854694011382549039697761004175407209558791854447179053, 3652106751745469138836394261068448964837586837946837760], [154022294046476191166601354200487272751456932009266564030406222693477250312, -3206955783329288355990916542931040507180115735589095742085658, -46556159424438993996266980041989607809250014411469239700], [-310818511402949181481718667905112140819910096388350707713518544187714563530, -6302677028584504608576597956565899882879571598554060806640309, -8402997673273830579368017610292821629425063021329983385], [-152845588005635046709519416664222842383461919022387580572948127138555905798, -20158060532713914805606944240152559716696175543950376651775980, 182479189686308972574250682449053333346456517481754183460], [-174200246665176332277591706835958906497932366873098838370468082041253625468, 24398425134949231657041287844303013025383607188631562811721757, 176140094735083644115821249355601424692890311369427212120], [455971853038853366273597117590494533612228597722172381144856447762195919382, -1047952006778856634288451256580689359699961042757959045123309, -224283562113141686804881929727396157510534786141669053745], [1044530475738380103437655037801255841810664582212841122822941943599787475116, -97593503770834840947353184583287754616934279476773559019310737, 12348742699093977608008752606937809857808315550071219000], [-1485735664962342625381315612871654504532388283021770074339390954301868532474, 45501464375757227471080133253468458795177468479538761210732779, -871361578135559792093857244999618139098921060355062767225], [-573224730626808615292647041379132006265048371371136250710849418606304342628, -196113687481348999983788282105175481690809409360703754059114373, -128953854623002572361437406423965703465976053400572846440], [1516372445893887240856217425500606780295298500380708798419243726401976517450, -228845520513491801783614550943532290615192729070431853207580076, 231013053408067944981313676067613234696119629182076915300], [3057751750295004439718952910912487365166301565428404244616136971149493376852, 37819415215149819158344061529956066852744752109415138022165425, 533150905573056605565993581399926601846398188230879903080], [1315009824273355813100566840275956203358715958469143387622537053894486125506, -134888426084386786148999978123392136092270745087607417782846232, -2952424846200415976028271480189262308870758145950431318520], [1667570756883170618411123074403181343570661551904583895843645725915154302276, 406412634277364381435855466850993212468110253844614606341626941, -5316685026603673232773185213251625416347776302021219320], [-6737523828333402675792690685492229632406691296296223082701524601935504083918, -620977614397184081974770841247368359854856347229842343814839792, -4688532492248486785921062878489225537770393445550238774960], [-10536889311222601166719302577084097300880471283729447030014965017327430147160, 642092655514569059742036818452349066688167127357506645545282158, -1986773236235433216847603204638660119799664371098426016340], [10211808986333169496260565630609341113422151591452955687083774721215470433322, 1157110022590926655428306284931157061414744914444268425227400554, -7624034520992164957592918897094521696138477607141046183950], [20621794259257132154106194504696195311052598167820383215397737959468007937696, 357016788610685423843549290438010780612916316024319165142094488, 4606651151555385012346924598701214488254246323490200991760], [11098701447344681031634306358368509984956279645067307885440684124526011776782, -974446023913119412852671883472652100227469709170465213744399941, 1460064190168606003253154629194124260899735791017529016855], [29508050111657982286232773657891234348430884745854582482776859395160983052186, -1574518081386359144297281361712006433067699781496535326890096750, 20369882884510946197796155076041752332487835170358696100410], [-24788167139176238405887613746892794369612471624389353756039118954958115865820, -2183695688838056201161126462534589559787686116270068336374533835, -9210652285673270504472916630938104435709658617430623466200], [1803568042073134953687975582356536489922446429863706297168920303845932742792, -2569109023036897878572749319691322674049672249886806303572356922, 32222721152490180431084971073908738902022515614052199499500], [96420866947587648551321451949734373742033536210894354602116527435099212476802, 310464185877588856519218574930185582678398838599361814635369450, -24929341470755601587240706761804489324282788960702442403470], [39886360937064832625811469649242208693200482533248612857091464676859368677452, -1289428386858309557023167381789732630278398410569914338489892233, 37460564157360813410687236326248145172569857220533517871800], [106954047511408252317398148613285262902958411676079701304365249446578132972536, -13874053648468516528296925047539291369886297378120259998951612678, -57924706821605936028073134388651823564212824071006621836620], [122442650227870071549156928571445317868991725642319923172466352075013174962342, 4723408544582984732246147031892293316332323293607857317034571583, 7516198881292515079452522033855231706124754988626784894955], [149866108208732023898781986803401199007037784128474420804837944199291666366780, -12386271850446041821084189637565488429830819818584729309689382997, -56011850820808472465652352953254234937699285983283893974240], [-337234957911577208129623527921903133837812242724210094438789190146498150957858, -14898709060059834809345435165492276735938636054148452412538348957, 4228515548184445625594893739706538169194291424399345660895], [-481126416691767344738570763034104544210697014472032816094898085334725220299678, 3185922056374073795512807015824514350813930501624725699679818490, -295989206288727504325427714649173768517981393247581163209790], [133872162215593469095754831477321714027584602974550088003985994394848581040846, -1344842702252265835104771265935255848362360317473589105604443489, 247870670358728982578466973984776528476639129952819352732235], [322201104420013857442946838061061847721929556341543142999618189899328932048612, 7905060835409458102974009306905949026559155275960184227582504221, -17152184245024063107783700377774271025177501969677981827840], [-340640052303476919564053023150738325862051825595352007665552764879068705272548, 13486100144515092733150779843265104511550824731004231142135133075, -425559485706589984448925065813631923093646192047481368140560], [-181774857483287429510035205752736024152928556181916613692464727371125480445578, -84840796876901146939956912011204137441096638348974510954031821661, -325296544226554777707138952156094038490365819045968952450145], [1242350965014979643099268535389899393373701980835359591494817642777329223556270, -117519187216777655911573226401846234320316881557967836962975690209, -823062362255307880764166569794999168520256672392602545905205], [180191205016400531897815417101245416772472576845751770355538884925104969474480, 187767473679926720747908336272315915558306925274352590789352385860, -26097271659919161245381347022021821745009163778889283404280], [-683928228025012378451800991911719503084982774096047828367164503533622048504024, 299192722394874284680295550418838065684319212657797270878844474702, -933038293656033636290857182317040564318447598987321931800020], [2842166456843198718591695216041457263581522935491631368215722692336520762870102, -3636448876656164610626191830461842449055560209069761162889172321, 2353635946971514839548734514286005102193741474933079597741515], [-2650530602459957987269923250667567914343619955772990638599047943398576417761300, -424611273107930600272133654515727726355957641711396331324229044057, 1105895556771195904293969845223175390163148439386088935915840], [4682490836683724974292716834523072451577331755706160228108786473213255920330392, -460309858107740942941106535201525883333951496234871464161062278910, 846331014121759677077127333231021303028230092406309443236980], [334159361581121678605415733926009090683283274426548902659782146593905850656912, 386900312428292547623032499666418685297122109595340522217734406572, -1689485456957456807714132684420316866801458746349064327640680], [608987979446439528479156976147301198041290033037630368094078484207039639416446, -308536649195949436999816089601918195227670685500989954557313998997, -1243138327323112401547088911554135657033360157397664241773945], [-593664623706967281883096701911281849976474978525953233191043053999496135561078, 494967746825411232830400676199916950587403084988209476582297485204, -4607590432913816678986696849054624124618437296215674217736540], [738432934019090870515101569783029313543206145950703945866499944459939981233410, -528494735836374401226059906130190830390613679939107250800950218694, 7346667962491701425129330835785420553162325891616556821948930], [809882402937433595682560291028355482818263184594147318998165991180914057050222, -735248285279780938649898620009394445374725594117851747504746547665, -2652651360688534284584412267790122292180197899058417020274405], [-18917488807643581207050108671230033944856435322701048694041060521668167242104644, 1028307342902027683476595449574453197484994055197689924196185398267, -20651966230858199825558800495258071451314897452024036923592880], [40562100757275108164168821883057700290107425139711273044460762726986382331097366, -1655023221749345393310192389110562952355595739766362949829416422357, -4582370137161982615582100475798669968312276103721417861287225], [41114748284079901067696216845914713755684341291535021426178255820306704394468570, 4334205804697037390870929741007298620806951798682047754908174106196, -4612951613753825624178047183371809578293853925078741019427740], [-23980885139826887325126840454235384462104387923967183770028246675080444903254428, 1288405039015878502480678003434540006744317357445504891112034567589, -13641777845607755415011420996453703125568310711998110882874360], [-31475445189643111243481981033164401315508080254691447269657129287381246078430658, 1361642871393908995833594614822828608465197640811519856139711310103, -3459962060804245338605990869972822045816039665830674617208285], [-101574650715129039173092411148256581307929572534730682041415842903746616229089848, 5184260936449608502931842490476884482042784092627983026949986308646, 7819284406911582982947511718905089558865703125430979708603260], [237136955111681723209198809088203024407883018255404879418740735043124554450519636, -2128329914901443917934416717269363658434496981802540024428980715551, 5488883347088826258207600053750632163874731962782645791906840], [-113705679550476452611987934050013394178309831560480235701000958112022314449094410, -1312577384697706199508901490777879923548715634811382721395065630741, -22605842964723831672108769459108003807574509310057523140757625], [-66072283360231172705392483291005443272000408655470669517054778686796562350722760, -4836512718786756502753821914363952239364314442605106445888118204454, -21278743122553700147189067268858085805315428382097346774012220], [76612587018348633046533612852088971363341338097200044485805049537478707052091422, -15232023847667915202269760943999407763790945214589407787210933061361, 11744947277706281504961424765223099017261580040926473497541755], [-151919098776062281327640320976349008808387339372088445385599565373069439843302614, 23653865206875397707871154756885182022873461115391469323386162108916, -36122948533400055092543515149763261939255762920016825284889980], [-69081974952879255253179788372360020567607512502274390500501115375129674375217100, 6819625033970351501116280490507547235123604041401142698963999871217, 187291753632035775047918254303412705496970724180327963245901680], [46986998455897527681998710984103483892280629438172249266744203579743705989139872, -14524148143268390398978507662358677570983085007938860239222030126008, -146256279419138937337095250571097554411761808379658029459298240], [743193843255567726181534825686614512086666850618299165557210739952846357412711366, 1189714076724326748943704725252576313028357551547553706932468813535, 76921801009174657916581512614366174077657074482695225387180555], [-175012791624316391192624854397419173447393839405003688125943676526903850517525998, 33647868704073503900380083870481509475737892562023801554961815243720, -261414529922443135362382654367115781009247219238080639366777240], [371389656914362971061085502739900465885105499373517906030346622490093677800279132, 29992941748200847326933995728889167046805496750112336620471824343515, -196510452768331973134911407409999376324003686201149572030617400], [-602100770662532234839464935661154620984097085019120366651805005824971136861405304, 20208350870888853398794771732652503079139864461404116281071084625430, -67348089801683403110727041416808890495499979562899825749788100], [307156651830346662413999626446531844102704870129665298568901422562198486919288836, -213830019245070826708957591427021383300192773344768710871526855099, 1008568817923071690124880775300305366956356342114389514992876480], [-1127035528586485614900169903513432950239487230554051901497543205129388078957055248, 75383529866965202265411018949840714395308900324351088138368035349220, 257518313069544098876153521616902313561498954121576779146105560], [1569203912702446122478030165585337411039948302771724809681130819939683387942235240, -69013102816627495488848268457431148845532528913557522179285647441778, -660301033473881369324735728767987888747602773534301392345408740], [-3178690462612067203873900582580922687552812735224076256392338989730647045622070430, -135081992043171580434982399275909549875909917147181883032982765129510, 174320509734264854358843977547547558775414041363684019344299810], [-4778999109048832394416586148399931950686562531565692250523973391079444294959212454, -152801543611973590042830770980067014702274541383540007988861719733830, -201487102988040982105030041275682647556292297201624034793922430], [-3109527684949560686815771205485111201725796428821731040509251968644605659022939258, 13435798457887769325824560104448593509541185171948565624443893801383, -1378163385587904439411156500680074094173346573081653724838037645], [1478336194513502707915221791343639156038523672274766816762718702956991180355202076, -99357459445859494518471007525662924047235884825935102361773166736645, -283092130116237244670901257972563938142007756494060433905854600], [6505231438132300553435324030722791521801715826124169098430887205230780889230409162, 184620773330132850785610326146430380675095547830220896811703924451972, 2372110208325160344746739538638543417507248314163523149290469460], [-600435423627041990983128630519143067024254765996707906397901459782738218919041864, -466646425298767571623097308166966237059098525045283732192469111207430, 2502426208787614279847559830197352227279875520972936905781271940], [-4949716698191718907668131126017333812571019062959757797926779323526682005944050748, -868708215155932391947380047429051561395999158844654259955700783039275, 2243228778621897828779433977420450009526417209890058623666920480], [2869338773635211135482482661793843836674840986163049573343570472375576775796162226, -204613190825645358315349283529526017772261682979610248883505746991358, -7498990513538908549737728904270941103040373234143249638123328150], [-4466644894943244556388486067735816515232650336393900524111640004012545178742747608, 192051520770825882882366072847731882886668172509724690935240052490862, -5161114548826931631272237556200702332952997271236974472841430260], [10069681819646600948499977170273583394659738589207188800323440844758066320014731552, -578370356510382997353351642181120131800822157253805364972048663694440, 733251282857207851017652672581930933312757360532436107841794160], [14954778916418385048952739710540880426161266250164256945515291404760572105107535246, -627252115943002953965986719478491051673883238469123331132977371257601, -8230392226555259169873594822452251920526261076510303124291063765], [-11788192934489314041346560162452605358026208285501569488661835923619173576323760750, -1932534573956503315383567583185474619013347314692172637349164855731198, 6019701677760519643736562055716108133319299713086311411967220330], [9389712250687008558215680880441273114208402403336016133782025798516421861030845822, 435392270278758243148707814560656144178768674111611229666434059677187, -6850241892653439724538142872485004373102956046792480523246718465], [-22150135207386004000301950366319806368168122676925764234597731445424167835656279660, -3055118717292673278574571264538649746688431815484639238751212004085183, 6792390066336890617501853590340298324192193905211039667719180840], [54328143463075286726078860669460866167762921475965072625217199412624956280838340662, 826660515628849955569088379892817819650805735215150747329144685884807, -1334828729857382324038628942369310059290812813021165943240796205], [2790723414382414357948085594538350648735258580488620042235543787460690415076920952, 1581683557924494308044259860850778681327700571819298397072406898873210, 19018433088407072394258330792002918598020134269208604983608602260], [17714372551236746849575873713539535176231990206610397855304166764679467202487680762, 2291224173076769973216713823956005460969040470017052506765976050600386, -10566941396304401648069793349988324788457435371885086843077115350], [-42555193144786455376592831170612446303881348449726697757536464747470211416101806480, 889632147347522731194593447346913901746747859905368365016661738899012, 28657693259118270079850271633891839182571965474533430977061585880], [-74973167213898042609341444631821724315699468117746408831468465621176839846655092630, 8195563630278510507238983146336236613018701419297638305549151685622434, 38931239867373149420140594345572908909336834902967038154222385290], [46676118116542060006581490034247617509142883967315188180957270317097628344423641972, -3978480780463873033037232974909073875932010604018060913962178640433231, -42858836265638212736011891661341594586403141321769774332063468960], [21997478148398758501673678046029667126335294237284507203465556219424631142110200142, 10146185130292555896830115921109758150728322878290357852809269095365063, -56117812590603934343662430401299122675853345852278162959423825005], [186243980732950759757730331388574675969058470210021475048404136045322597448184309592, -2946472084274436768017186517562942282758868951497491238969814162352814, -11102007955178237407364857309681742755332078337766670220764242860], [-95061499277215847200686994290783216173853307141864022327373039729166864585190753530, 8171681485966117268236756261327083078464187788268277310661093886676403, 79892820297628974624218358378680476601613998648432247962014499055], [78508181323415822861276879063661219880411387854330903183353068693197282448057797056, -697133192420891423660900391172462255415973603874131601369798254385008, -92320385679657663600704668984555583577109651521240242982391143200], [100689019644516408518363311290974546695961130295315105835719472692154786309664097932, 10727945044729943449243142685585871603616317346609817655727934154253871, 86421626708035662515487439952823643034651867910314753364294104960], [104647577063418036945018651668215656982819040249907608050697175004563390427892667182, -4229999731746022176998046286041447094068581243716839173212229863430277, 8868464794463662196623515190622509581727068102209315617779128535], [-278005014588448802689176366481805999576296477147333678514531231409255464117424414534, -5463058244788491234474563420965096625229534922002979686090395131307262, 125725635710964387204574068611859284346263639793811050980056531050], [333185635846806917789150340159218957708763548647021181080336575061615930247814718512, -9051858137001056801219673405260000322099889845031576724460946722025548, -100784315239436586987541817113073072991557046482119570975779486440], [7984168503504320043290135016603148278487866586953292596183034237326900078405523230, 2411145852471211047496779939435909998250049150891941344396785359996123, -40189824563639397016216545218052093020612442177323401140729161545], [-175205221250187746533234412758828319442193620013886926083370565392848683120130660394, 35342399339100307133308388567166216345774860483835576227648208395722779, -66707439809957530125117196131607770397299231184462652928689010825], [274076355932422893565675082719783328382042737559634935804663664476678811265559094892, 6709366328543991416204216734639521420411455746337526238338785932694199, 29557501321911791972808662202664830255585379122015058334602226800], [-510960826453456844944253788507730508155516709186165544585588369468793446094469073510, -38666459456043705707909824521669054505018747587935085125468040147445116, 162662951800263690286397599188124850732842451090265081511238498900], [1812833045661416525463641333946571669923421274893517812272700431926287950882638305152, 4534906380945514474972016821353149370105333760662346411674939239186400, -203580819890187500075250156858474305308828392573982251192788871040], [-715760402521190582464781653769848034175096024950001618140823810119025638436952778878, 9777724246026717350847314769189023857885950780381242590108059080280264, -963276711951643128921572666903127745734215976118688094488902281880], [1586558495943579354757372591924130940268504664546531931409649272247560020220529485572, 33387285424487581720016023684803976130870832999462037253432807114064597, 405748697305974664062422498739524682909919579688695753559404445520], [-1620318345939324187609043129515346763345023347921184578856548042342769754535018832068, -53552535080339271089894162456051996246792745065586261015879023182114029, 357573969254738975605524922792938948575308788612304824939199312360], [1227018472694345491790399613881523541543386077397350235527248307001630265424457822102, -105569455662705213548644463283145220786364471724125693679208796743919585, 506093875224526426164856721344337962243339585828410054999083843915], [-2035869575957818903214162790484496413126285589920215765381853545337126242126699442644, 11911755018197161011222236882412867161399104126580368675233027062344167, -984810093950551738334539021831694201945406220836976442028114269200], [1307066646597298255139573360480793690288424340327342334726402343925412632305847123802, 62513684467383604287065688303351615472017313525908268338682360472947602, -199956047498294821165943249144102107094333520475665507605663487430], [870741435004189329398963773206734533143661494710348341392822299745875659028740224722, 117349775680362678630197482862650450287235491184654051077943310149604304, -1190941019299309948423863817728481215044441576988031015832310657520], [1353839827543827522543606190556018741519197478159180502652207578357391460843437967222, -383708232538208432151607184022772177357809684492280144202545984082554533, -2136075557221509077783259767077523398389261215289320529196378616905], [4621703130168063154271158907317659099587616049154095282706394996800862211643014698306, 290377253435930138959711247842943569360432146682233259585184810932150944, 885368843326124337169323634926020945282544575428353806614672558880], [2255424317576316476724791725899433239329468035556403980399541126466826294624916900792, -151348011336042143268856694890559853270801875819244437592090506698317846, 2657833171307038992796332152396482018747667062252531240538009123060], [-7306773043197200210465871813722759850650848971750270382532482693574559586641471232410, 151986644483025208881300935808216436129830808795661376491989835965071099, 2603987644601685658046321872667661511603662317496965954080997063895], [3678933963429827827129605032626850775843745310824203939544893420589918545829643456432, 535883447949992793626731673318656564301348557844007089629534868094637956, -1534669199077405475067578549349969278371486296921345441710892345400], [3911951115299986113794565925408927866890757155165297238002644381199028754324285828766, -296735058097623185128210591721539964971338193983311614763041323791110521, 706648937132645569597166090749419878979174755686366439301255939155], [2676547798285140669528683364516533068744252074328881018611329556060050901676816695330, -274481790105797475280516913970299236041299387170116884866137842328186624, 4580949488774254122216437584698209012881362487892127006602961089280], [7005820431589020572245622172693568285777258625500399884888396217571507485354719010980, -185661384372497164447956282914371835141362320398138232778995328695616827, -2190139243991996048422737316384393964008463905250880227927280702440], [9870116798060208038564506056020422946847546335305784079206199104314728779673777676086, -721261632691042949558005861667351250360673812575562114574818208502273241, 4320995758452665306169469161110102891674912753351588485769807692275], [7020454160100443534660257997728693497010542215756430864325200507670920041636598567680, 570621694404989564839340540213943616637799364614259127572341585061616832, -8847894194117844310791725947784901498695556609636185114721078849280], [-10796038851922057801647579844057125597276141177099205599247843376420963655039346766388, 490687290920284689127203540948606668692073529090641682533848461302180271, 10034891116513781172135764391684359370233305930135790892466430040880], [5320597324796177579543609366424297571623118931056032859861826134269046803827933799930, -1046760292175040294993993181087875677494796869150452319407730950860701206, -443821257332501402914337010026928213955353469197810895513239468430], [-13036451838847176038266773861844148407450305213069461178404842869946653828633000563068, -523190869652790623304259023200662854360793248704449324805602436894231859, 2876517811351956148631182620361974698335538373737022901592449071880], [9323631797850347140384694976227277335001242745470821893043726623814561247749583059826, -764209523395342297307275653896782589168210648641550406913250603197206750, 10641038933811269959200185920138633581884711408098172144063934981130], [-25121393017294129829701478951963966629372503313066581728158346186067425297999072230818, -730057714037175342449546842747330688976524428943918273299748395400559309, -10378830450716801092796241451814563324720533924505409763964301312785], [-17498326704799008653953565080834981201179675780055509891294736348404059198472643012888, -1292546994276202565322991910913525156622238790018155639784126754316382498, -20335989534229560970481590774425371144784389925515059167034659376500], [-9497895893634681378589312871426138886794016162754719135871126918246221614618121797004, 363123772476877038163977747308866815871929853594257175880657817659640633, 17569111111206289213762033560229944352220976274874687216431290433160], [12079362823603725636551396570544740731731964419228773366758172238185740336730258427480, 2645273812448653702006873761388774186988734520646772410882471357925258770, -18892180723983234796440574612884929083307775523787281560915270964140], [10514083981133167190314241681905221067292178765951270602506226223404213990273653492442, 2460033618821690623027036645921555863231852083814201081699049349909727348, -12695298166244211845953886095044930935832745720536205593268379624700], [-66581278669447314344836317668512885873969701109251846697832895509430881986841271849904, -533340884123010409410584399407274186098716796032197999882164379435095044, 2105096108730856139268529995339422800034804342799350099352985089720], [39664940326602181548278849963143365542513580744101017899303140652689342785038985199922, 1554663696782102533818847823984007824349925697187698358565013166900753714, 29659860445666257431701950544109607718512326201238605272421901630810], [21305863047211146309711354915972137522187622247059132551922102551213761292636325460136, -10434591059425661406181916991530122534530788954872142179094764852885684050, -46437380289793368555074958947298224591718484280962935047537096070740], [-6599257533843199702727135968692271520373129330098290612676715169425553076194054891818, -4874634759645192227268941770573194033085157525904243001749087292420057473, -17067026636337787500433051933090654675200718400328815080266786430165], [-135250129775405605746876597843687736703013595284080872232820616026292145836702736765938, 4047720973025632551090530642773249699102767517490500782540071741105117907, 77358557398523799007067699375452948168199039661398992736693060579855], [465422620240760513816996172437758410749549495151555109018347375000413345931273426029960, 688302544833570905069805662778081200737618785200259381082374489554790822, -7962346670768337124614050493311434776222017220347946121118468451060], [2084211551861779212507198586470062513623310629718463091889082802411364066960139753090, -5994327249603477751785645966749027603099752976501258362107609683132161590, -116420929949737976161411427439647980823290286845708679850312817786670], [16238291612645212349246767903721407713455769107394425706910065880508094270534087483632, -14802125406748816854927540174569300802370758790346062612643584801853841708, -182903441991616160777469616383025054886069599779737309503122155746680], [-198556162562219760342160911514508168620399932927491906912631738131641249320567965213124, -18254632002433895106567379912819297663387539587815130915683318509240016413, -66113599051322185090476752765132397919929263033223281040801884045640], [273679619236191824750265868031782128425141364541635486505187717035742182423948374096350, -12512938678370733553880254793164381384828467202468686190643338311280295529, 179533781924197283341276884132444537911454337572049470237869429980835], [90245292640154224534379796129324493730093078941532569514771360273930083298196779586282, -529718038633860745826069042477301663407676824875548408394116456069040950, 331072274087544875462002928636574883657158785215245623644524521602770], [76300107071556107710196115778665238337647257461607598821651155444954722323961908083040, 23740291706858912750144199663769947682377898154728062141877728271037085576, -215076595264387690910589904068515803546314293123790100862773595773040], [678841094332647320554323795114872210638692444219529989155631649153872838458280354177496, -363501521813650254565401188354131433394940671017114713768492690842724926, 170301293452560908707997295989167872144225129209392081122994313767780], [-59956289966477253320679442739403317556840186851419691270090187651930202266257121059868, -57949403090304985124397634421936492056389364026316077919091159329257874899, 41081563083433738684981605472157167051526812089761274947053719652240], [-108196290339337247495418219804748427405500374524038544630279178424376562797306769798778, 4808187234598800428144861747006430497013188317225111733647588780528050399, -83914480298619909056648367627130470754263839142058859317339504669685], [-933676447043593497470145276992220811788509338725012266811790834254468931495190933984740, -30457079742478326364821947744980317172166718078809248757025235380259412661, 95048054048427164763472056208512146498008298944469807247514925128200], [593777966044101040916957990960571442443781361564530996566255149002653506548810695605312, -24483271957139448492341105214300909062044000230857776434132695533506231888, 165690639241777123431690969541300768813503312253205690415737047215840], [905232163151368895360558291697747558032428256185398536950181496674049855526386387716922, 43494824192742029921827282648261703472600844295873166084982225547156045634, -417291582671896749995292661176838116786429125800455427714135473483350], [-2054082046717480061647697534372684412318158052300976165861540806475047308531495467222588, -27345804359258014802322210786458492588945868695320461426861053787658548459, 261863578183935136979374319286665295304200467949267360659633326382560], [1354720823294068746988634266640692732730544359953141577721258552298756501412645636400816, 23619913039322611773692402302701889402152290215835663141510184808920452004, 32271758545052051004745808821040007847433514777950168174045595404200], [-1141547279083317851293678986507522637614159131385567798918169090929402072189009418523470, 108778564319712090432605910328380707057583936383495221940909779540312940274, 427596458911549431894358055018796323889101638204732486859168588250650], [556691688461214837736353366620990460366479474339498231475758942748522096644532200107422, 1388293288414492111760659551545174759166898911468628295041372340455016451, -107190924337475754690583977212929767015591031564424216268881093794305], [-508649681954769071897644423520699692866730073775635832791448857833415577640618864208460, 58320376841240486581109031145129871067212781357517282072792082298605769753, 572821460396539515242070454887607999364598380138896134238755795799320], [1523075716159439194923370205361997715910981650267181687547483711347514781047770165779352, -12201052048693548639632627463110093828365781726496897938808682343964209310, 356385998662058373727641951703645789625563220936211365631490040629780], [3367921594357565640006989069298561708621899696881148580571088181038860508441444165749212, -81161842491713424520758290669452111443461948766828579103258951893704020557, 399564213993233925647814019291580563661317752329818809171636872501600], [-2315199675363455683408989055987441407586767931513866790122239130083313212976602307573868, 21094549988541948659345003103015003526535522108794046829902262557201550321, -534156046644015662882492877143236272801530487531986755494232195515240], [3091223286791265761519489011096028967192574132107464219834499999691041918901658076388472, -189116910826238944741985122873247854311251999886439574980699904364364316934, -556140449666016243898773051154176601852920585888080176614916115550060], [479329590669060789989026509788287282682566340099534486389469513620706749690125123286310, 2103135403518049836081755535643954531761180480593094662214368180581732707, 1460228266555773399695246425892986986226437736355544529976439760760415], [-1902198348536475814653365254230189748739384302012653204830736209997983820792848659502478, -245254415857342318104489650860726213254556531900543584660942562081493385816, -998078036198158923873151414792841207129624663770725426238038591901240], [-2340795421281597674375379499288258002544027791430694864434830978097744673882571761558040, -5520106064285121817951705970463921396116100503616859603455919693733173506, 1054418714030025596634199545149833957503219170527071993132774908488300], [531008766052095685712434608575252605321755097244174015141649690691553412700169891484896, -305391347477761577095117282289814502541068942519966746798753985147875465288, 191477978758646481012484109776055849138190440872924339344703685131040], [-1871973217618007798765267442583299030949684940485133066526650198152147896436010591011668, 246767440006120087536937306722727901255498459989098583696592182597295843871, -2153419730353612704580542132146352342131891841650146049473650431297240], [7754962203120292141606282029605380864055860131180468016023464068613719895077207525876580, -429055041438788044396062723670896023181174512789366579111921813772989946243, -1233160677910164484900046104317135056075273779370365996688711474249280], [3164939945103455542570278512933730572605714159153835400519497453660775568828723854721872, -330514253975291127510841785813720167121927381511727724632338719156265159812, -1844825745173929712536929683531921668100168745130131438480991660899720], [9848683238217678713975279803518030681861691989046728309529271678435355095927765465826806, -344560766480024134432542376076377798871268489652755115243045572032491110249, 2004571765792679788887191813293431349281564664353633108863305563543075], [820018205231986510430133158645375656896590218549773566608605371185720430632121371019202, 629706730588345142948048930741154960654774390122305338894892273127231807880, 2246337724531320052619524730046562449062719038574260939343448327732520], [-15646795504921079518135279059144931666295856698974261160196548614928418322457999431784904, -94144462069936766800876447891355041745880991498705593516572292110514643542, -1498091216340893147352185777137127582653638242763653008933307162745580], [-11061481166799549558806811135115735193080343851299128462777263351763633366971033795703110, -170206139135863960294949717539039596484225418433846579827133241763816852790, -1151409765135029720191594937498145333275296567980350296285052702361390], [-11766042001456177854954926255829324882068435966246292578305002252079958814494762486033178, -451653193172349520419963817463409854348250411908946716405357824227748937673, -3605986969453394445744276984081438259233828508284281679696914230842045], [-1219101285481720403374648156030503424993520935252088511668005214605676211770537498915460, 753532873622272121456994541261278953336756107417869272334307369804649873067, -1948622822799290819615869870827583867418296003326884500580376334566640], [11374425682300138506693186172826677127351426787381237077026748535039676547329327730062622, 575900006303932593102839326346028231229365828022259110169704704885830594379, 3662488053187949531484867445322128408098820135224414885584393795176935], [-4163667893285733167898527194367750346314247989976298505704632009917621881918151594406604, 271465911486321970601055983553321816320916242537057293827860989389483587841, -3429595031274998114452895382858871671326468772401066998906558499116800], [16098498330006653725970455310459840557440275548406092495152898182656638841301345391643406, -441821866638129460905800786349591038269469525666324201371114857184640676273, -1612171612665034740769139122640466245888076124580522802836794033307205], [-21610941925815089928549858231305535132657169934344369938306216518015955699688629739652854, -567464246264951179052207210551542269522034737887904869674607513270090422012, 1586967758119473549418392505454630961940359495347365475794928338436820], [-25111239733774507546312099597439486577476095159596009412921056749014278388020289683683968, -1046556895324170544952099051526357308127909927409642846019100708055209009696, 7620144849679827936681165052045870719903998835991186000025057356931840], [-2846332401954869540243659639011345338778831343249878631539071480695061009411193615877044, -842302045888992709257571805661125976381625053147561192935605423785236016801, -6138270762324824590935103382751982904303774636421661360615980015450240], [27059628034664907797347287088698875699436068842831989602481282817533544793805307104935150, 206900945729010696464697639397467998515705048770771115759867166302044318999, 3664764406793343868927141991961215506922567192207657812049888003472675], [-4810600329592062712223798568396705590879329028265946267252208254752188195563002823291498, 2474728351920869939331429132517800909220253335576058042827665943531113127527, -493923077357647062980033279234007382301890757079406413632807252289485], [75731076693453882495342442298203398377938747285071319002175067357496618587861531971790946, -1797499447415666120415101964331885369855995154697692173976587894703211278806, -5785254945150480443160447212443888582991090874248218384687191044794190], [281501189171496071576877555670428182149612527897707125168178752229655547109397210786860, -381815676651042866535236967284481498475331373161905144270694759474792066193, 17878726900421672544629921502985318590104183174986129933935545364419160], [-67226127857253954034663319102177929838161151273247379982758564526071097259152200036112250, 544043566715112788254455998586229293915022610319562180302297976751191825527, -16120843208918727511852940653885630814091904086101742210477878672879485], [-11433716825130967014296975776248985770823655518196962201968023407860417311445279270253878, -3385728842283975436803096802288442457941138217388650555132049221069436883526, 2362669719221652057204316789168920488116677953750758890791468668067970], [48114998027136465566220472525601752921880770789511865144716384345242302820290768309496532, 746119429061402024182534408718103495853862921224536661602463528698870878697, 4749564404411072812023027980646742060595815586786585158321128738979680], [-95752423155475952613358628655657717104756359958891827664243219208453450233712409164367698, -6093868360343456444531461807053634148289181013059417523843796127650804579801, 24132579631967638322927392955356740541130969243612887463303620507838835], [64053406608541927594278622133260830111694384609790705208135344177146109275672548437058662, -2930593832030930353701153431138863089843633938035894849186790164224843866613, -36618830360903995568181515098115536996188750780980642622494052161164505], [-60046569617016092437748391786471895260502866856453970016621674507224888997117416145376004, 1703486043293120491512143783398947969459353927076286634676220863819823016739, -55082696570422918853834114612226900858429779215375258094386699289261240], [9187772971634307101314877728213602328521341807331127069842423651938927638170014023410602, -5073235646039715304703243444900745548335275556334541350560189891606180984830, 31006198294008212360943505614346377096430797150640095546582414972433770], [124374619748929703102621124169773183257949982476792802510179180852296625615295512216964640, 2350646422992027278666592686461545468699248894381089596009495081777944036280, -37171985264476660875680332549355209694489637654934479460749945742194480], [-33845904674063463211923550926629612189350092946256205408198749732542311712978929115276654, -9167787133676849320943931315074920703275699653087488249477495647817092371864, 49123326216598940190262973278135092087774944343665511568220005269841800], [56357983899137602535068925247119594722529495872045652704361798734508646274388498627794952, -7663293284103591975176823264931668660308447037748375918121602925454103660986, 66332396460195928320644752441495093059856444620345175387612703692695180], [-83545967804608301532095566037379463619353634728597202805147956964100821597377420621957484, -12317424270519202895067108646472504462051966248875566768575486818521317384911, -39021586280552728241044194778173696804137565168873295373578546731355880], [42800776057124605805713989961028922047304396326036224204792763594315048262601020601462070, 6274346994219562260484771103989123808950686244693141019446724110967938507947, 103182094428180768689937930210183505763891634763334379414829325457167175], [14284562124665502637527850256783728197436059518716917560931643412924392427368066531324922, -4584528345100208073247752172580177430972923581761130443231406576969802100246, -66875840484345018006779339023725402883008383934784219373719230063435150], [245468685218431794279181453575135387864811759304717559740629521203786796860762803231857852, 8534009305894347888747605425689299439912208600042176380633848243302954207555, -76888709319159230235868491536982368037278261980991963167834734475135240], [-473462153508642184923124749403119491259003710920246824761130221520939554902198471956345888, -5293795371948029927754294286951662733321949303992778981983114164529971886632, -33184390726881629374487597717670768157050778241872268119111858737478400], [52905536521342370622077288225786643300166398368885172532576335023845583490527550290320472, -1455373938339541032742800697386627607673653537844821478372264343319703467326, 111724093807884071816276697951059244931302626523373259027632525862346180], [-124660375222660178926413154383239395916094097762006380279963581566794937419569048482805304, 35741451361954661410580700564002470816889939544559108664422520859538811769654, 7842392609735591523577898991125737663949244398894182638138211315812940], [-675318767239777182510056340294493449123517999666131131767540268426269873307290211071975378, -28776254523518323576475316261095071644495266816014880283939947434590435658101, -19278248037891177025367178415738456096885915424374907316298331911160025], [480438308879011288322126308273367121292935493781235089968681926567329768876883219769602116, -24315389298114449332604074852928816862058160666691546455837789452289291329179, 290060517559967656275542875680977557048649761206378187457597775795719760], [63243686945610814544803765081923091502829459571616371327639651571688490700361557812226352, -40183384649754049696682760016935637674819315921418971489571092484760532595020, -300432803187914873084896292876184959780488106297417947774141192010082600], [-341267804859362260691579634870959767389091848976893012698054314571394402077011718277927118, 26090398871418370341691852368182005107035683701442041138280195465593567640482, 273047416379333820143844475381563012678596818610261390155632421911598730], [261501971016441350941956103017475503156109139044929154849412037923915765563547399176098846, -34114146561353751091473725357774973526167594597880921758259297984490437256289, -29644230636335562159808899661437409970131064763394469953084468703825845], [163406354293767187284484363742217704834435739101732943467567104677470938318118527390910120, 6011554463823491761370185308051038165890120998690082911971447848106086009470, -463414316677651834456193769609059903018004497310025807797169408838636100], [98182757299428893491385682172763714941110038145552257745401758151638117251811691764140450, 35238679438186891951888762976964050910443197814477373185388165027810017232648, 47521732374603652095151499372486718612037995146054269478094128744566440], [-704104421282104948200758339017191728785883482665521060483141302387955805405607577130383418, -67975225563847799691434752014384682388604356315480416517142920707939099801329, -293527097861701031780174687049241190413305660637664346883169000750717445], [182848089513700013808766251040037458609680296208877430784250196673144103536400680978909276, 103616092217062366198798935360354658888403453590485490038997566841853026807179, -178058062562570489322801782773443166143817878964800308060839293387565640], [37599893306048491778639725509889327330478792909668353208971789850774927783608733685676042, 87177257180690104720908747907522096755388320345874732729084114838117649596826, 347996534378439755169291322653497529434680293418122040284329717733347810], [1200259621387827917067104785200409277393880630798166421460595776997758287374247163923084292, 49984191829855910240079212910491198749852692035874243849962371004429099274093, -367607442357576786315058593678525368875203955205674288052133225651219000], [-1780455808083897614807328079167695917923162691277584939560761979726066031833863615341124698, -42931734328061661704906329475218100942119820720111542610647342542696586292961, -262785376204829077007561085500936596195848936253879176065357331346479285], [-1374705654848511895536814942542953791046942043897154140017646619481511682963872748700328810, 33431218511274654721859114323872530190956106686429154349442608919831195641203, -634900810980292710888878494574650769761050091821135784007757949184199505], [2623933490368638943258261942808332254385856438161766369948912602341609971491530396039309152, 59447606262610029559260859895707926925258535061386035071159793428302483573400, 246688317506131525380936811192968932298753777590416926118578439967214560], [-5445928497022067993000755425627085276278406238620020226372824380337452611975203090742221378, 47525605416050153773146613013100979036392863284281302519950553977186815539835, 686406442253330693620941720299996509612278314004851335593106163631529175], [-4392246741199831910846409527343848260216636099364930621991305235972898044861391706403882540, -169763746080165693152757991215571945799045156570262064632684138380499901337247, 598355878985307185086214957294085753661963219898948936888672925488861880], [1305984305208592226113552001121385140185428265066442233572538870143686687522617326856033036, 340458746099405232775279778770590690426401709972140501787999551661435866583, -388385305888179143155659215074317827237638050042903532088792673697455640], [-1982990425916957714011547706793953641177458845487215413601321917402671682082735427190955718, -116559003274078631435407819992488500617152478980412989565488280791210119712172, -1678427409021275076874586319275133266108448099946482356784016305654294940], [4778505142354942932495946772146247048771072821594956350712809779058512083847864717302031206, -176975901504213130959309552055997396594405147586878979626611383573529913478549, 440472275074927383288339664584597803421425470365853640586056801495875335], [2264827697903510367985475592997975577478603035931390844837885847180574228229991415355659440, -93506441436994292365217947714643253990799082726029201939947016507609344458412, 578585061833087612471888582429463766282463746102264837653851517150998040], [-4903625875913785919978591952185101720735137610049972760765057013339709913445574066604422148, 67173593523568443616186657663083913677442835464699184039783479920831745532475, -848911403014267683258547491267730650989886477919291523188274695594379840], [3711096578541374324264491909283034833119590173486283856408459786092945769497948194753737652, -290999400209197432726515931686276966868269588253191370165259739456288445755975, -615700762890073537935863051530428719208157331685769421204012768296011080], [61056833708891971438709643829881461221044311830167702523302096278395199628361217677741346, 30070427411777825292518105613737861053099761306137457435489158776652386846362, -1548092964808138866349389594939896429378838210617862326886667077679242270], [-6331952727582366568698834857384873478648675615100643814220273623231076485623053453241201244, 159864666024367280332273241463675402018776158484465241611844359385792988965813, -654255941459569493764813380385561185008951307496045740223850485899075320], [-7967275001484222722381978149129233045758368603024897234156522273915302135070890366464395450, -41509773761260426683092312172403299672186437004420777301024685083663223401869, 752151614461118957053670563321024990778283121871301885732168964730547375], [4704875525787712665433830713791541649143854567467058675127271650716483292858752561260289800, -255240161394177104995957257076218297700245135557468792466658913483064936027882, -3838303672870228004225703576823416885813382301023016268642160653093080740], [-259184521388854670967498585487817818420345395308950647715787113453072282854986583113833618, 303668273350024243662997846484314502884156041930037262223746899750359174806991, -4983590850412398455398746574040033348924871716974884149806246344170674885], [14696112866016757437955006786545658460030881052813284664100979244587117283305476021454830192, 14220641505788764552546296945578477073356261412164593324124456886156264725796, 2947090549717557539304597414859287438421109045159400921534250504239978040], [4392432348143856955380040960542983694672224958806195729076406103839161706837322820261998430, 825552095626094249861059383418610110912053101737751251236243556620366100536915, -2482191401141434502149518275751472115599339142168058782480467387473824625], [17550623192082171005593177632203669013431812395028844706447331775311269893222542801311259362, -179823316396291648016113748741414992074458080923997882925314966717620945389478, -1413440112731203647857392165622030622022532531194063056930272277010209630], [-21358746554954086712726231621030064363220501597377261580101147554088667850187389211932034388, -555173859281243301236268464801850796163463098424898912666184040776017925811009, 3416707398344471852209223804312782153522567936362524012485278159492729800], [-6818030772840945852583371006703434782877111870349221773873489085922172835632431727910337704, 766363099344205384995861305878888961414451644188942387070336271342597330201810, 5278204805243420390339009325990179119078893543378201705269521932992890580], [-4094173050648311253416311845818803929865495238301909739755596373949119071830477108278167590, 395796877143873337404452787539969665780871787280255401590776231912305727413690, 554471437639075125009302978975812278108048560488041965141765291828894850], [-5315369410608202357060131649956915785434667725964305838801647547937626667299024314558208100, -858036570078126079139154907746828670526383885751602048832222982949405200355485, 8073833908893576658113567682728629966556490891057944200468805077343900640], [4687208596211436966200736862479110155948240041367137174049083039592764765316909461194139072, -1361816033638627196185674101943086024130953898780963424021243646550986687070096, -3558632167889342171748637690531701300786071324742820856266056287708662720], [558608720988644391677253494438537099935369763278664379825208615692264122162547868460291522, -615362977631861376292744322602029261136729389575435341217624504656125157394688, 4023852081386453821922234541535512736467641776352180008092399190658384640], [1097478686013183459734609831638254967344131888136689298849469191261262480818682754566520370, 1835413018709120292350251197886873430642092928508857377796981239729719920435280, -4270269136404644666605177150142659570256189511613102225080375535334144880], [37047214099171082570458467077349109736956620619456614048059090085780715585640370726703729532, 1174794024761244272443275713000177941455236477339872293493614991828699992740571, -4938541601957504643518783276879595672717071812122981925000266841664371200], [-10740028754326883315617222880861629088812468461313717448353893478654394757558194457041107414, 359030538453592385371689320312549606640035304517733629864013055601991496417588, 694127265265983247984912048696701413725847685751177944389400277316322500], [-1075825642988454076352810891880949825371113167571777010389356267094426728124721483854294058, -1251237211089944882213372316565143149372381203204898010353287247114885565533097, 776729186472258767645163805117957856136287774009052506322045804567869155], [-27736510818686611526618444584711084346758532248694355445229885390907753588090823222619660128, -793026412048752181157204341549624200617791222087043519548699637951239553160744, 2744575259597610662990970334587216024582266342362762993881183929667806160], [-34761905747547398946912820283883156988820255918217231329149861287230334404737458412957380198, -1075005978603436118761219590863366162248777323353592301289532247134427647546540, 6875851828587752073700065388397157611750740361677616939657199755594095460], [16711505905829942176977840189005085435688136904479206253712817162177556723968760651734033682, 1550702706533745566843423128992304859181246784896187093624879388730284576241426, -153223691832583609628799544996683050337239382907007610103298903561347910], [32024569259212083292150298697794570053600179929050519526137280255755711546020282657478326860, 2025841857579735905515388359820535071519147185927629022586446504657544915408703, 18220658668293280764284580364978308124563707034616517917227802399214767200], [98642977535138225702216603579630515061838195370770173146996509592871869963422144992515614452, 3625155489545590852265796669209784503959569756746648812475517560307887772971385, -6850778243945338776729315415640880174305833017825692396362353520907463000], [40716183244503179551401856766310455655291669001062850902182075848026515509544157627552898656, 619127803679467688999270842157457651669291047133616263315376072849986179396280, -19829073660874516681318151574248238861905037513189666808704244182432843840], [-67009853522323904835241107952479876783640499569481938942022334983626048209179531187417733938, -3722950532140590517085444965527051841118837836494914848933735584553872814213965, 19467859949873912360899362326407160298160472315891744995870145383124349295], [16707847693649813364989402831478432320188448363722706683086167876210086567590619494000096902, -5200173996784945399194208478712112334610930312339313045896472166286300870871605, -31873508089756592144484473618106599524264283102574830773072878405587471385], [-43147743167201472560107013773551189235887893529470390685628193398153247820064181532586945674, 1691574868336938180829701500227548914822484886823515907981327726573044611680991, 13994068779998582608937297114072670127983570416813787423251506605215848715], [-2755918623016331042087354043717957761704313572150467265274154608466959351579045380731739840, 5687397109825992210275032427221163735052765428418232023425257692281377671362640, -4402641118119885205125062430440010125352088911232359961838347117515744320], [-141640072701907140934488768696321261169249036515736798652414287674224918939048573673846197748, 229437403950756611426371176473465106458073315704674229747136015079469978751687, 5022006491586445741520968604188500894707456077543089275794091003177303640], [70423855292109698575937905097263037933568712769531224365446435614892788284029108334221518532, 4585435271660511297049800402239918670043858889238497745380281179264017502689781, 63138372522534725231333303761294726436373893663511769358996773183171046400], [-92458735424715231642282778406773245225909276382442682368714337748827704277818493791511412044, -3652731058465266010736690819296298160404499039490515072403329562586489767802271, -15286373519350702793883851197342187810414249759971635851333898836703386240], [-16991909326315287873774699609868381969056247501479788277797593376553295327212152441351060650, -2895378869163681021792233215923652764499166601617687427900109260653551332157521, -68152384483863574833930122166786079878784919207100607853478277857793961445], [-107984624601693765684711902944559805597853255277830693946995416096767818876315860325375869918, -1290596200586073962786100588924315375842996940290179227667796605694334980995608, 62329657908411505761350277017341379760124999021761607007170050666370241800], [1176443538425107769793243361207446224718624404806027137153352473116172936008086896661990682, 4330380241343624904716160914892133133724624101919010556252336151718449951485586, -29257492710319273145378823792416412117260492086342611159857204395437491910], [-219847632421502785032239711985004451753099629714184833594165590013530658686988853322673950064, 1636771658307297043941168867217722256085678829197837872902282750907531795846428, 2640528500065091292046149059061212186834994641377412208758279514107411400], [-50474764076997624094760190654613953898647463872774473070916800417714449390816116906206582658, -3046121316396225622252543806641571316654476015608193785799821359831421611727325, 83084928779457777638845414959575210882502955785944380853013176769985581215], [-63999585243292475288050191296708869865383642423850745226561484802589293704974137689735357814, 5893801786585442391801223072009238006432455393444531806766922699610482256701652, 251296282821235715314892504640290753396105732304601275697045551282399460], [32090926099987975654247684941662462855689780043031085589867057388983318736192908034765181550, 6063630157405683491922975942907571595334658974006215079779493650967270568941407, -5719690326948157734352970308360158851591184420504321541797781155424726005], [-53332402330744338155562670445012404640181921803403394378142819832677416614098393151902756488, 3101772982775416930972917690639928193860856738304643098357959336636008434369402, -1372709839743132018007849626034455630431921800056171989493424388338438700], [117636156479602227596744327158721883801484657327518076228923402850362593172902664651039230742, -25226527476997980985929476306035567201124084174634817696476006289647597693452253, -86034933944343702018007610571196725877337692999938547134058238179395635425], [367451572715531809849080576229281296465043648238419943106360024428021096725923784851914504620, 2924460738230096957609198442297870819035720572313631950245813954734338813858727, -105367481808388638830589962845970043768862118757588961912103204378618826800], [-304179054726657979455377032928093354275848800949603882007656789637447619657093639638153839538, 3059389810663005603264903372622922992286839908692483514000095956808002646813067, -166511531318525123465201561429865509018136033831798123271342196305383727065], [328789920472556503202823956107787768709025591889567646240462469122949657979964744338083803236, 1721646673436521314023467729387330170983086568967579566516355201141625577184357, 23720047269663730629327051291435422443818639088235826032224432303158705480], [-143474540362883272449830180592877194776192817208666033878103322423547376466660471444263958448, 17884673323457447458964825353170825758266930730852913354919836319620093598241340, 101282930209682780565099754914472299258250036483732417879449333822775345400], [363215012876213106761203077437554419155508303990684887750204371825401610265846802892937411646, 1019644596834277606594612393670806321571408700009461808606872635933181339466363, 348504331864102602863390714730560445967172822819199135623905210229461975255], [-95962350607701643495986423199431199046713429840295978710500481965600707471012695743978102388, -34964088071063720073973116378994226016975689657511113771753777728189139469747393, -179957100210590201528966937706908330680447926190484052605680241429547241840], [-348343301768696222667102468788917522546866603888501484547638236896534622683324204105355408454, 1298581502187058469464300739754960358150648188064089300033004475740822942887156, -179155502771607138891764763420903508862123371015356110723521753922901413500], [-336355272023776053832476233754200371186999414901266823314077832189022599037421401813285903898, -2996625571029465208976453516883065640439128839225511482915012100402685391507445, 147214557191010919172969231093530143421173467500489186695580849526384220455], [112129934086758643572346369260138348104079203258139049838817774417166498837055823833017128752, 6855972003713191895103175037097353409890868160377624147506814693769035486220644, -188347530308754774497029649469043886455264222132295236716065541680479099320], [59897417746477549003849986196255606361489016355415607928052312700089751045800019980093596190, 14888695121863585243519876139363389697124408749446183699619892423425604412152891, 257302341198758292002387263047968861506052713647334801595240105522554905495], [-226895938038710517323381878101528634771220299201476157411128256501097954014570251648399563478, 36566315342174975201600789494570128828145290459689461611327956999722803926020866, -251304413810938084696825170316013077939097478878067519511387680587172796310], [382135403111146384701941283999393950939023907371258859744316358648417948875361331836851541920, 10247839180318957485399836774470634387617135371588679007847428150239837448196504, 122555297969026541723362422534618708111403120576653938310082395086825810640], [170090743259247392246454978102266143419155419574765382090378660370222320989306053293204489252, -20621569640502820547258447179105766479727283261966351903427973378431504191920835, -175765243790113279499514417869563523220748889278484130736758157480818097840], [-89108961415924372286604692280752190549495498416750411771368236219805887299428470825100280814, 40591454956473961215562708854676201965896752884857171645070460018182508600839330, 68102010135318535039313015973283936139086172395784402239743402141724474250], [-517275127957777307189731514049062605562092249270746361327691567814247156482435872278890075768, -52187613962515175515750374883093447204399965809050208413292614679321033476743018, 275476271623468636033777817974779344600529077864414437702695011368641925180], [-5015614988949221007124141743644210669073369510622918342862875066932138728374237804845200914, -9181208333181079561637692982584336649373956275411321804437409184796961108530297, -167562159854386244324617918480458428934714101886393926774866942879940141485], [-200292215725534387705560257693008948666770865174895111826295269418135165798093105307737168518, -51652763027063010758194891927874305386699193718841842945669952873247382189856534, 35683893519683892074553592010242113950358589648870062435007311354316616050], [874459230963908227716224569724916256506052678061889295181709838159071158807921500495113993456, -56702866666300414956827023992071113523367796469585439894036562095160780885577724, 61228682513193968132870656969505480742145624159218582722802907529584057080], [188233097019662398543003636262637994900425790899793437657187467140310477827178635212612695540, -4133906514977707774914292435707443058278542716073711975824751088100599900253375, 298381165852735021245148022477049818585768782372688064796977499861901937680], [79501610930365136526074478755557344826569608042772020906812699944817555030167008666860415276, -55194514220885485700423329943004509907731753123109218235382918016173147844100297, 584979356776529007124036195216029983477225717023007330136413621083614946880], [170371181064721800498868297282205537709488244241528437820657858809325768886042118727910646362, -107770153606742796409749769990337839248616487864221956701762830922428101082808142, -426285275126496366575636886148732195026422943935625511102567324217436421670], [-29147502632036864651056179555973505963899885211618765453056473112283275808972628720035072634, 7449772223782131014972782127967416087172548269955160239434798100032138608806235, -144296176866541637408722352973791707730739321772089857703383889419857834825], [1588768649155040388988805087388754194556134735791873291546281201099222942515248770411537796792, -2243601273039979978998144273192385855178211110353135093336668108343871048907702, -972836528190334517827396583754708168244315121769406685609169748145779756780], [-2095120522211974108487283483299863746567104018791810839868542244635037492097418132452114177878, 54019439299498179714336362263613392141128383240895212277236554236220516847675604, 330229484939420322387330773511107417596062955448014632598500764214333773540], [678021522148760087297109823695930185319522754616608738731261047151325732735303843404618060012, -70399400765272856540362452968487607042453944258057853569399234807117749094783873, -724793646204788829180757179043652448143017113870427246355926617610805728520], [-3510811784138992122302518079513142906691051143371121499495899710202162115748435505589943702620, 63097131766075698031172135396420741977563891831617962028848856034465207436153269, 839098223056892817760162904638810971044631647924448038121243528814932920200], [2091036795690112252546231448695002953269275083079610441557340232479606193625776501068219615632, -70311043898048547939307756617951874128642227599884461580964445258932600933724292, -297251716885771227940341484790533648529217782889710909394053424498159547160], [4704931200371192198786709664617396735945486836077344188679497480185605541643629823352918722430, -63416326919453364986413056306301548317451439396770873663493692668157353865859929, 1394818757392172428642301471352716784078407178408879473035969130814021305075], [38624697759863712695256102963899601731413612133650664016073084767995922979627948941805595912, 91092074516877915571632254764804146743697100092463607315720918755341517128938502, -143115481374611485972207092279073734652741628609128935562480895444906785780], [-1631287474899725888610554550850214812202693179734833497990139765868209497060510401974381045194, -259442499610355597763346589452370166916420488577802163322306715101121737672223985, 264278350046586372820598594223423211533621176506853695212541960747595119355], [-5296392513819181818246922995124225014072039071267425213465145507570627979068052702566890849860, -164323190398072385342242426564051319452955059205095127220378991375130028846225861, -471201766266461318652255624807347025037786279791321384831551732314147903920], [3752009673481847274996264543778095001569048839849372788467119350356509955062424903307099107552, -57808929584536951930618460899051661367187382870033724188927477589543380557896840, -1015813153865158395306443938144469070895381341042062604312145584724959294240], [-1754191686567954652619870100314507360537638365393250191011866868269205104298237666778294001438, -398920700735768059176017179145162802038806153392799251845568040729325285326590816, 892920201180871658852168572879825611282688637331317030457099611026187950880], [451136367512645948792340391143635069279840011877761379704221901866164893356411570870150987090, 647290929347074305394367279800215848812571310975656294696445956385100285334797650, 461252582913580065926788935807018435216405223038876725344631600028596781050], [-3892609105397595049543773682005587073974139030882171158739901039685419586465162660904564442294, 297687514702576047874796092451280737194580563922113715991161444383059541371418884, -1868250996805370703277306773308881793163623284461723928073217457358244848940], [-8631439727101578083074245171857372944822852720794740208248778383205313961526504249287555522058, -300451014068710654464681890431180928187919987251542669208764472925148064651527217, 661105706465489086626041652088101462986865174319547739782150680204641213115], [8252992436194420490623364222008241378419392647845725242344080971119350174501738667716181971642, 347911534216184761657819276996728017505935310128397362649253289616756389823683652, -1742653661392556169764617907299337435150893851333117009855592464928728572140], [-6947148618484631508187598421054967728611778849282520520767449055721324551943130997085109298264, 370511640455171951192128945361080398868114128830968307404247806651483063717405182, -2857579605078341677469000197689537361348663892183725730691274390716808992260], [2433445133348495897570510421249652946810253301946292172893583917428463249092236102982390091426, -203402222300276834136022778492685249863589409189905038837474138085861248909084256, 3012929665476243567881883831963060695768981453308667544846828478331094064160], [9262516283665742112245114651321309631822574297336817392677243740392039305900216108140853420140, -213493624254960849209079040832541943922734642772007097262094855520819045635782745, -1389362466240364035856837466899616563866780593225045255490386623601057029600], [-11813826664073382247611321184325166581319207911361412921180331271554379827859908662539336283368, 718527418508174981212629878677792708432050965174294507249179923637924378563109074, 1520552885953975738861879074095325149309365349903280288697331872645158459620], [-8397059578476628167057550181243312443532362915449163914127428452698094328567788805774285695728, -599880582967695873260742392635861151645140641549524699079787953293598720448668036, 2684124453038179515965685969676198248313665270684539585537387919054346976520], [14425765198715665886813194021691994106215553167406056553450100670591222540801453994047152451326, 416418360559761387906730363947343328442632717866035825155672155652222062129442607, 4780332890295843675623943853116816107355427540284344593747805541279074545435], [-21124583033438338989570608217016510620340879373683187883943355397178603484610922795795291907308, 232279141674130086961463995372082879339898271434766071960778231936260148666671417, -5075308266202467940945476313963963807537164744331364249655874967149403255200], [15701502755272433088216379574107002685848385794265152570892200972480406446438194709922709102976, -406051805970800164745664181396212160434310994279829190384546750814352062646397824, 1296411395975027747508961165999387933136418251758966223170472508128775029280], [24187445075339382753918081015432588464267552706428234876780543432964366960985623652903976116610, 147701088255838620867020846861588119289651620437084653478718704907258366942013160, -1370174667135330362733659579512115837034271430524204660198482792689956548600], [-14669099809090492930884785342666376518440126927568648443455426142566531669881129089850900555538, 373972424239074415509438214462108153204911880156584352282896311079634314222905679, -4345345909991094675441247286542174062290656687379869854669516578181873454405], [11806445742153055649386458623303525113256839916460685563607201721741561059943137872790088212740, -25993048128228497705947271953331201818574755715681032999619947205638650285841827, -8275035398175513007361279500794185872517680684325794413119003069140544605000], [8100590144016285071151057723538304746122531693617297718085598525749066332379573244494849177916, -418573973584943628825941934327833069596737331021426075349600578676692917756459093, 9160267831397225536945887805276493893933438081444921977323276494453792095520], [-15402208872850098453506554490972153082204511774955703807391137600048805442233415815728411828888, -1012715160906005972341624481004152592491672817030110076682993591486785292659756258, 5061645781786988960642115962093671428699436477610832854219237505216567556140], [11258005411120271397632087345594558772580777986911476544240664387918347545673125341326584856042, -1126355170298263239877846736000735899711281242180860033017440755540456105382359164, -589559245592991853703685429810259367405122007981757953385719997022189534380], [-15023544849342756142740123573611125519609185010547188451300200448469944346121741397574643004320, -1247535355772678772579994938972409056446855539934489738545744454463258259979468280, -2094850630404811108229269931304808029991904865782170386294287418917070419120], [-64360326859640410940059786132376513192342340383464632131852057295182227792894069588478119590, 664329992674230144801713672651022771524754239451419391257891671927905905074459428, -4005456821513860713632280372993065473952733283329124859460245233101669783180], [-7245249143227307537492822912101353213630529217657266628330144947782124152571376189851952421148, 30458310074727172688983914619928878298247767433678568983597980435998696490000925, 6810929176634536694976053868665120481272526516943730858601428098304141291520], [-15860426197680291493795999967811264560725389353476536288515639853280315550307476112773986467138, 135872266504959755065976758795690000861452952082714731884759428926058927263411527, 6081327320952824965803493705140583271107656210072735999915010784576675844115], [-26328359022374111544971772175019729550580951575558510702262526098424719699323795910332016594570, 1762836433458019023260258599600902826246776759206072481665150071437974875565735511, 3947499899036914561776291053885247016870919328560130794421463921762997836515], [3717076637644787196190121126526998674226016287064737294444493869831951531540187814395538573122, -949006496767688959952683774962388329694419829845099018634166972838429140154692166, 3856238151537333961585459324740975502282693813718965100633088513092800595330], [-33677612211392661687205296170992072568212550561437292349771244647673734683671973081051554932304, -449503525218388583630185367066396067426404973796568359459971182146923758494227708, -22869229567989038692818623991708291244377523760545317461446265467365622269240], [3712841897102791959035777075775229352579024318467669524814834399913864131700206126843973568426, 2123190396986983686961728101611191626221627706057363883743493171697265844859121892, 7741117616985814010873653890592977019382023808817195266385032760883123747380], [-12918453828048271509250359465657613782193221309953276572881508991004829645040189038222416957810, 3637500046850022881584796387888152563336475596220279843128454894646886416135863371, 983347750506853363012447862213719623015587393337110250219489486098570667495], [-68221805839126601511345686816942724323592977139041945689257007533133468455137158781563803394408, 1645463531271557939762711827024825671294101329768317011041836170081618676329254098, -479908931318830701219220075602009463038362917224789795828788873199262941180], [-28703939232996084243641035261227359587427590540679782821753150091734298177177674337354252626874, 97608434638653426020751179886011652898280369016224082586990924782596913067962555, -10296063225988425924696228134535220597624757706221786876046560878816923642985], [-41651534897161886655508391560995750453213136420502984195254881129263918902240472654907490148718, -2208596677915527348287301960129725228789989347728580020916060087058170710099281134, -9778048777656215725523468254501455184643938988064037947775253441433232003910], [-17009485532476850961334277532295201136633205560935576162082052458720269860735743993260910394148, 650148857225578720632900809692542070101687558970855575451131105147369809727069555, 13804894145668594631508905538748088291404993385449915143728684628819453552480], [26886711333404297485946730724045579918324706488313325208841200635685852835442178756202964969420, 2272837601450265038458808006543127926407145713269501006823773317698983874579037223, -5733972255242294165385870897916091944645981868437854298452642887086374888760], [33099361212669997499771938980325666225637509522073134582035747437383840189101015973443387415922, -515166705888108433968420633973312664300473951095296721886026861723073445586432792, -36042926157655056701833745939694661037044939779892459545298684798245729256440], [53882156417109717095671004733369332292871164603118356343988179684869877091355898398145840213086, -2559345526678002431769802031348055785593261441187861277177775146376010067006336297, 27120782090924280798388445764458764245119246386451029568030091358578787483875], [81541704366906508916434513782590743895019945952043565671216410027965611211668924647979783535732, 1035720900519331385927637436905296650086414374326099411914728243472229217667085233, -4979618405279433167269344711460003464659497480716709590974656760826569608160], [-1834249058445688392749851516366079337205605428924826215051829012738863104838734952559864039508, 1261202198283552444244602665913741477154568918770023581776309082638069990447027863, -20353213286362875270966039604765670176287922581639077108283906632041287976320], [5073778890911919530779765730733991621816460349981940524898615503553898834537014586124157775066, -3231091106118947311073900739091636751162826470774807788834715927956001163268907598, -5465848053047227832495315723985038846982684953671797071232236914098446790950], [-98968573095149530932817688278340682108951198412637296237914539903436018089105986590311984999418, -788792570185663194595105998538370907027323622667741968532880223992985713007339189, 1739187639925101669555917508734147851143816038539679712346799789049004333415], [-114709935659489859564127471351473066336909980470245790831417863240659768368818855307353579074880, -1762822083544616382515076802697363520155373768010785794844293280280235151345596400, 31086026995551472830352331749592224454944225249544859619927921098426497228320], [-68041172498651470696556819080010245044153487875837854419683636733271558600120352314822399973064, -8999829221995852548896859735840240243578273221050190298079818412413041618937780022, 35313915241130528973854686530662497123579906405206664955099902514436920943860], [-194738416643021919363104984537954280124158343754080812047311547077598616474633371558636121945294, 473583653453092300813810049351316053103036756735843693259630261460173499659506546, -13516951523626748669879916713781811604865952583398849982217544032498879596390], [75277653051642632239245113699501434032215847041539681956156824133851455518459333758133510234792, 1279703532104638252503088769104215535667304865494092632127401931623185231141249198, 18208652691393036962903024198810305765950201571245370748402308258450361474860], [-13999146517020490145377528563048694606351501355699052207118190533964078099098249844653651861290, 11001602770861764898132701486829978030464943708943995704235257083208606752039626179, -27722615031628781734212473265693779567273948184237625809429472326614883016385], [159846382386384780258677679464931594090022037976544754549720983081769825680680170962100871255566, -2338464056269504082755247359515116725298729327901775487425864880946758350863697929, -1830635329396272065211075467841669368686597615654297849306170675014326589565], [5329627190516975782537359551836154972592015056738813251490237401471392793318727604094425574416, -7588766779574281155098105267534225072793796144370321033691740903346922108601930820, -8263274878776553488535208227650007908668888858391513870343961314125637135480], [151789451661865095801141488386815293429687552360450813597884873655171756765773146696170124413460, 1815777242316151317199241051012133993580352573887601933016968172696821278766117385, 109540990559504017705006040617005878954785797356485831939112879784026427263280], [105392205767662627371090924586985366195095685651689272808844191264833774775518993469465399008122, 10504348899483176796122783398532881595855619516534578380556878904241178420373769684, 56215237006842900721583561517674859365870019741128215067626517520066513146340], [241529210160458882018690429361029405876084848848100807812624299322912518231793325351222438342566, -801077745612707140630374956056707483940219539767630263167330094529813122737003933, 127203639778785836539626872786168667943356021860449982883719236145564745097055], [276372531249928300476734994517838867135234056318721778576005721783328122493301059744903928174652, 4046830662792865231026141752951694842181417393390599257391552631703121444054935443, 9158337472680096922730160472749602173980096453472294163818887743968278535720], [-411815965758905092585983030954468312259141455410109547284058205788649886667423175279544029758230, -6939711694050224733009691035138772803427753963069996460123839071658113193315359222, 1764310104244897226818205033316618359741160573439668028153887592825616070930], [46679769933102395147575553928814826961563981970414910875557199336687026598407787309508034376692, 13960396915507772044511474907083599976433590152872259728688352289055013088303277353, -106543786390842211201426015065124335199219968769145071996878807310407740823720], [238565388114234946332263180073292977494007418250001876106543904633392450179781666603620937460040, -10262175348652198926396846686866944736118827911342691636217964553929454573517737722, -148959229737271667187978855474407260706211020486531991627470860347939384316420]]
